@@ -62,6 +62,7 @@ public:
     void undefineClangVersionMacrosForMsvc();
 
     void addDefineFunctionMacrosQnx();
+    void addQtMacros();
 
     // Add custom options
     void add(const QString &arg, bool gccOnlyOption = false);
@@ -86,6 +87,7 @@ private:
     QStringList wrappedMingwHeadersIncludePath() const;
     QByteArray msvcVersion() const;
     void addIncludeFile(const QString &file);
+    void removeUnsupportedCpuFlags();
 
 private:
     const ProjectPart &m_projectPart;
